@@ -1,5 +1,5 @@
 /* $XFree86$ */
-/* $XdotOrg$ */
+/* $XdotOrg: driver/xf86-video-sisusb/src/sisusb.h,v 1.15 2005/11/09 21:31:21 kem Exp $ */
 /*
  * Main global data and definitions
  *
@@ -34,9 +34,17 @@
 #ifndef _SISUSB_H
 #define _SISUSB_H_
 
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+#include <unistd.h>
+#include <stdio.h>
+#include <string.h>
+#include <math.h>
+
 #define SISUSBDRIVERVERSIONYEAR    5
-#define SISUSBDRIVERVERSIONMONTH   7
-#define SISUSBDRIVERVERSIONDAY     9
+#define SISUSBDRIVERVERSIONMONTH   9
+#define SISUSBDRIVERVERSIONDAY     28
 #define SISUSBDRIVERREVISION       1
 
 #define SISUSBDRIVERIVERSION ((SISUSBDRIVERVERSIONYEAR << 16) |  \
@@ -63,7 +71,7 @@
 #define SISUSB_DRIVER_NAME         "sisusb"
 
 #define SISUSB_MAJOR_VERSION       0
-#define SISUSB_MINOR_VERSION       7
+#define SISUSB_MINOR_VERSION       8
 #define SISUSB_PATCHLEVEL          0
 #define SISUSB_CURRENT_VERSION     ((SISUSB_MAJOR_VERSION << 16) | 	\
                                    (SISUSB_MINOR_VERSION << 8)   |	\
@@ -73,7 +81,6 @@
 #define TWDEBUG    /* for debugging */
 #endif
 
-#include "xf86_ansic.h"
 #include "compiler.h"
 #include "xf86Priv.h"
 #include "xf86_OSproc.h"
@@ -138,7 +145,7 @@
 /* Need that for SiSCtrl */
 #define NEED_REPLIES		/* ? */
 #define EXTENSION_PROC_ARGS void *
-#include "extnsionst.h" 	/* required */
+#include "extnsionst.h" 			/* required */
 #include <X11/extensions/panoramiXproto.h>	/* required */
 
 #undef SISGAMMARAMP
@@ -433,9 +440,19 @@ typedef unsigned char  UChar;
 #define SiS_SD2_SUPPORTXVDEINT 0x00080000   /* Xv deinterlacing supported (n/a) */
 #define SiS_SD2_ISXGI	       0x00100000   /* Is XGI chip */
 #define SiS_SD2_USEVBFLAGS2    0x00200000   /* Use VBFlags2 for bridge ID */
-/* ... */
+#define SiS_SD2_SUPPLTFLAG     0x00400000   /* Driver supports the following 3 flags */
+#define SiS_SD2_ISLAPTOP       0x00800000   /* This machine is (very probably) a laptop */
+#define SiS_SD2_MACHINETYPE2   0x01000000   /* Machine type 2 (for future use) */
+#define SiS_SD2_MACHINETYPE3   0x02000000   /* Machine type 3 (for future use) */
+#define SiS_SD2_SUPPORT625I    0x04000000   /* Support YPbPr 625i */
+#define SiS_SD2_SUPPORT625P    0x08000000   /* Support YPbPr 625p */
+#define SiS_SD2_VBINVB2ONLY    0x10000000   /* VB_* bits in vbflags no longer used for vb type */
+#define SiS_SD2_NEWGAMMABRICON 0x20000000   /* Support new gamma brightness/contrast */
+#define SiS_SD2_HAVESD34       0x40000000   /* Support SD3 and SD4 flags (for future use) */
 #define SiS_SD2_NOOVERLAY      0x80000000   /* No video overlay */
 
+#define SiS_SD3_OLDGAMMAINUSE  0x00000001   /* Old gamma brightness is currently in use */
+
 #define SIS_DIRECTKEY          0x03145792
 
 /* SiSCtrl: Check mode for CRT2 */
@@ -603,7 +620,7 @@ typedef struct {
     /* sisusb and sisusbfb communication */
     CARD32		USBBus, USBDev;
     Bool		sisusbdevopen;
-    int 		sisusbdev, sisusb_minor, sisusbfbactive;
+    int 		sisusbdev, sisusb_minor, sisusbfbactive, sisusbconactive;
     int			sisusberrorsleepcount;
     int 		sisusbfatalerror, timeout;
     Time		errorTime;
@@ -679,7 +696,7 @@ typedef struct {
     ULong		xv_sd_result;
     int			CRT1isoff;
     ULong       	ChipFlags;
-    ULong       	SiS_SD_Flags, SiS_SD2_Flags;
+    ULong       	SiS_SD_Flags, SiS_SD2_Flags, SiS_SD3_Flags, SiS_SD4_Flags;
     Bool		UseHWARGBCursor;
     int			OptUseColorCursor;
     UShort      	cursorBufferNum;
@@ -707,6 +724,8 @@ typedef struct {
     UChar *		CurMonoSrc;
     CARD32 *		CurARGBDest;
     int			GammaBriR, GammaBriG, GammaBriB;
+    float		NewGammaBriR, NewGammaBriG, NewGammaBriB;
+    float		NewGammaConR, NewGammaConG, NewGammaConB;
     Bool		HideHWCursor;  /* Custom application */
     Bool		HWCursorIsVisible;
     ULong       	HWCursorBackup[16];
@@ -771,6 +790,7 @@ extern void   andSISIDXREG(SISUSBPtr pSiSUSB, ULong base, UChar idx, UChar val);
 extern void   setSISIDXREG(SISUSBPtr pSiSUSB, ULong base, UChar idx, UChar myand, UChar myor);
 extern void   setSISIDXREGmask(SISUSBPtr pSiSUSB, ULong base, UChar idx, UChar data, UChar mask);
 extern void   sisclearvram(SISUSBPtr pSiSUSB, UChar *where, unsigned int howmuch);
+extern void   sisrestoredestroyconsole(SISUSBPtr pSiSUSB, int what);
 extern void   SIS_MMIO_OUT8(SISUSBPtr pSiSUSB, UChar *base, unsigned int offset, CARD8 val);
 extern void   SIS_MMIO_OUT16(SISUSBPtr pSiSUSB, UChar *base, unsigned int offset, CARD16 val);
 extern void   SIS_MMIO_OUT32(SISUSBPtr pSiSUSB, UChar *base, unsigned int offset, CARD32 val);
